@@ -30,7 +30,15 @@ def ansible(
     send_command: bool,
     forks: int,
 ) -> None:
-    """Use approved creds for RESOURCE to run an Ansible command."""
+    """Run Ansible commands against an inventory of EC2 instances, using
+    approved credentials from the Sym RESOURCE group.
+
+    For a list of available Sym RESOURCES, run `sym resources`.
+
+    \b
+    Example:
+        `sym ansible RESOURCE all -m ping`
+    """
     client = options.create_saml_client(resource)
     run_ansible(
         client,
