@@ -24,20 +24,41 @@ from ..helpers.options import resource_argument
 from .sym import sym
 
 
-@sym.command(hidden=True, short_help="run diagnostics")
+@sym.command(hidden=True, short_help="Run diagnostics")
 @resource_argument
 @click.option(
-    "--mode", required=True, type=click.Choice(["basic", "ansible"]), default="basic"
+    "--mode",
+    required=True,
+    type=click.Choice(["basic", "ansible"]),
+    default="basic",
+    show_default=True,
+    help="Whether or not to run Ansible checks",
+)
+@click.option(
+    "--inventory",
+    type=click.Path(file_okay=True, dir_okay=False, exists=True),
+    help="Path to an Ansible inventory to check",
+)
+@click.option(
+    "--playbook",
+    type=click.Path(file_okay=True, dir_okay=False, exists=True),
+    help="Path to an Ansible playbook to check",
 )
-@click.option("--inventory", type=click.Path(file_okay=True, dir_okay=False, exists=True))
-@click.option("--playbook", type=click.Path(file_okay=True, dir_okay=False, exists=True))
 @click.option(
     "--output-dir",
     required=True,
     default=str(Path.home() / "Desktop"),
     type=click.Path(file_okay=False, dir_okay=True, exists=True),
+    show_default=True,
+    help="Path to save output zip to",
+)
+@click.option(
+    "--timeout",
+    type=int,
+    default=60,
+    show_default=True,
+    help="Max seconds to run any individual check",
 )
-@click.option("--timeout", type=int, default=60)
 @click.option("--did-update", is_flag=True, default=False, hidden=True)
 @click.make_pass_decorator(GlobalOptions)
 @loses_interactivity
@@ -52,6 +73,10 @@ def doctor(
     timeout: int,
     did_update: bool,
 ):
+    """Run a series of diagnostic tests for Sym and output results to a zip file.
+
+    RESOURCE is the name of a resource to check.
+    """
     click.secho(
         f"Hey {Config.get_handle()}! Hope you're having a fantastic day :-)",
         fg="cyan",
