@@ -3,8 +3,7 @@ from json import dumps
 import click
 
 from ..decorators import loses_interactivity, require_login
-from ..errors import CliError
-from ..helpers import boto
+from ..helpers.ec2.factory import get_ec2_client
 from ..helpers.global_options import GlobalOptions
 from ..helpers.options import resource_argument
 from .sym import sym
@@ -23,13 +22,10 @@ def host_to_instance(
     host: str,
     json: bool,
 ) -> None:
+    """Get the Instance ID of a HOST associated with a Sym RESOURCE."""
     client = options.create_saml_client(resource)
-
-    result = boto.search_for_host(client, host)
-    if result is None:
-        raise CliError(f"instance {host} not found")
-
+    instance = get_ec2_client(client).load_instance_by_alias(host)
     if json:
-        click.echo(dumps({"instance": result.instance_id, "region": result.region}))
+        click.echo(dumps({"instance": instance.instance_id, "region": instance.region}))
     else:
-        click.echo(result.instance_id)
+        click.echo(instance.instance_id)
