@@ -3,8 +3,9 @@ from typing import Optional, Sequence
 
 import click
 
+from sym.cli.helpers.ec2.factory import get_ec2_client
+
 from ..decorators import loses_interactivity, require_bins, require_login
-from ..helpers.boto import host_to_instance
 from ..helpers.global_options import GlobalOptions
 from ..helpers.keywords_to_options import keywords_to_options
 from ..helpers.options import resource_argument
@@ -206,11 +207,22 @@ def ssh(
     ssh_args = keywords_to_options(map(encode_options, kwargs.items()))
 
     if not destination:
+        """
+        Ansible will use SSH commands with no destination to audit the local SSH capabilities. When
+        we detect this is happening, pass the arguments through as-is.
+        """
         raw_ssh({"p": str(port)}, *ssh_args)
+        return
 
     client = options.create_saml_client(resource)
-
     client.dprint(f"ssh: args={ssh_args}")
-
-    instance = host_to_instance(client, destination)
-    start_ssh_session(client, instance, port, args=ssh_args, command=command, wrap=False)
+    instance = get_ec2_client(client).load_instance_by_alias(destination)
+    new_client = client.clone(options=client.options.clone(aws_region=instance.region))
+    start_ssh_session(
+        new_client,
+        instance.instance_id,
+        port,
+        args=ssh_args,
+        command=command,
+        wrap=False,
+    )
