@@ -12,18 +12,18 @@ from ..saml_clients.chooser import SAMLClientName, choose_saml_client, option_va
 from ..version import __version__
 
 
-@click.group(cls=SymGroup)
+@click.group(cls=SymGroup, context_settings={"help_option_names": ["-h", "--help"]})
 @click.option(
     "--saml-client",
     "saml_client_name",
     default="auto",
     type=click.Choice(option_values()),
-    help="the SAML client type to use",
+    help="The SAML client type to use",
     envvar="SYM_SAML_CLIENT",
     cls=EnvvarOption,
 )
 @click.option(
-    "--debug", is_flag=True, help="enable verbose debugging", envvar="SYM_DEBUG"
+    "--debug", is_flag=True, help="Enable verbose debugging", envvar="SYM_DEBUG"
 )
 @click.option("--aws-region", envvar="AWS_REGION", hidden=True)
 @click.option(
