@@ -3,7 +3,7 @@ from dataclasses import dataclass, field
 from typing import Optional, Sequence
 
 from sym.cli.errors import CliError
-from sym.cli.helpers.boto import RunningInstance
+from sym.cli.helpers.ec2.client import RunningInstance
 from sym.cli.helpers.global_options import GlobalOptions
 
 
