@@ -40,11 +40,11 @@ PARAMS: Dict[str, OrgParams] = {
         },
         "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
         "profiles": {
-            "prod": Profile(
-                display_name="Prod",
+            "production": Profile(
+                display_name="Production",
                 region="us-east-1",
                 arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-production",
-                ansible_bucket="launchdarkly-sym-ansible-prod",
+                ansible_bucket="launchdarkly-sym-ansible-production",
             ),
             "staging": Profile(
                 display_name="Staging",
@@ -52,11 +52,11 @@ PARAMS: Dict[str, OrgParams] = {
                 arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-staging",
                 ansible_bucket="launchdarkly-sym-ansible-staging",
             ),
-            "catfood": Profile(
-                display_name="Catfood",
+            "catamorphic": Profile(
+                display_name="Catamorphic",
                 region="us-east-1",
                 arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic",
-                ansible_bucket="launchdarkly-sym-ansible-catfood",
+                ansible_bucket="launchdarkly-sym-ansible-catamorphic",
             ),
             "prod-intuit": Profile(
                 display_name="Prod: Intuit",
