@@ -42,6 +42,10 @@ class SAMLClient(ABC):
 
         self.check_is_setup()
 
+    @property
+    def _section_name(self):
+        return f"sym-{self.resource}"
+
     @property
     def debug(self):
         return self.options.debug
@@ -186,8 +190,9 @@ class SAMLClient(ABC):
             self._ensure_session(force=True)
 
         creds = self.get_creds()
-        creds["region"] = creds.pop("AWS_REGION", None)
+        creds["region"] = creds.pop("AWS_REGION", self.get_profile().region)
         creds["x_security_token_expires"] = creds.pop("AWS_CREDENTIAL_EXPIRATION", None)
+        creds["x_sym_ansible_bucket"] = self.get_profile().ansible_bucket
 
         path.parent.mkdir(parents=True, exist_ok=True)
 
