@@ -4,7 +4,7 @@ from uuid import UUID
 
 import pytest
 
-from sym.cli.helpers.config import Config, SymConfigFile
+from sym.cli.helpers.config import Config, SymConfigFile, init
 from sym.cli.helpers.contexts import push_env
 from sym.cli.tests.helpers.sandbox import Sandbox
 
@@ -49,6 +49,8 @@ def test_sym_config_truncate(sandbox: Sandbox):
 
 def _exclusive_create_write_fn(args):
     file_name, body = args
+
+    init("sym")  # We're not sure why this is needed, something about ClassVar + Pool
     config_file = SymConfigFile(file_name=file_name)
     with config_file.exclusive_create() as f:
         f.write(body)
